@@ -9,7 +9,10 @@ from api.utils.setup import setup
 @pytest.fixture(scope='session')
 def app():
     FLASK_APP = Flask(__name__)
-    setup(FLASK_APP)
+
+    setup(FLASK_APP,
+          with_login_manager=True)
+
     try:
         create()
     except Exception:
